@@ -16,7 +16,7 @@
 # with bdutil_env.sh in order to deploy a bigquery-enabled Hadoop cluster.
 # Usage: ./bdutil deploy bigquery_env.sh
 
-GCE_SERVICE_ACCOUNT_SCOPES+=',bigquery'
+GCE_SERVICE_ACCOUNT_SCOPES+=('bigquery')
 
 # Whether or not to install and configure the BigQuery connector.
 INSTALL_BIGQUERY_CONNECTOR=true
